Description: <short summary of the patch>
 TODO: Put a short summary on the line above and replace this paragraph
 with a longer explanation of this change. Complete the meta-information
 with other relevant fields (see below for details). To make it easier, the
 information below has been extracted from the changelog. Adjust it or drop
 it.
 .
 groops (0+git20230516+ds-1) unstable; urgency=medium
 .
   * Initial release. (Closes: #1001622)
Author: Gürkan Myczko <tar@debian.org>
Bug-Debian: https://bugs.debian.org/1001622

---
The information above should follow the Patch Tagging Guidelines, please
checkout https://dep.debian.net/deps/dep3/ to learn about the format. Here
are templates for supplementary fields that you might want to add:

Origin: (upstream|backport|vendor|other), (<patch-url>|commit:<commit-id>)
Bug: <upstream-bugtracker-url>
Bug-Debian: https://bugs.debian.org/<bugnumber>
Bug-Ubuntu: https://launchpad.net/bugs/<bugnumber>
Forwarded: (no|not-needed|<patch-forwarded-url>)
Applied-Upstream: <version>, (<commit-url>|commit:<commid-id>)
Reviewed-By: <name and email of someone who approved/reviewed the patch>
Last-Update: 2023-06-03

Index: groops-0+git20230516+ds/source/external/jb2008/jb2008.h
===================================================================
--- /dev/null
+++ groops-0+git20230516+ds/source/external/jb2008/jb2008.h
@@ -0,0 +1,30 @@
+/***********************************************/
+/**
+* @file jb2008.h
+*
+* @brief Fortran Wrapper.
+*
+* @author Beate Klinger
+* @date   2015-12-03
+*
+*/
+/***********************************************/
+
+#ifndef __GROOPS_JB2008MODEL__
+#define __GROOPS_JB2008MODEL__
+
+#include "external/fortran.h"
+
+#define jb2008 FORTRANCALL(jb2008, JB2008)
+
+extern "C" void jb2008(const F77Double &AMJD, const F77Double SUN[2], const F77Double SAT[3],
+                       const F77Double &F10,  const F77Double &F10B,
+                       const F77Double &S10,  const F77Double &S10B,
+                       const F77Double &M10,  const F77Double &M10B,
+                       const F77Double &Y10,  const F77Double &Y10B,
+                       const F77Double &DSTDTC,
+                       F77Double TEMP[2], F77Double &RHO);
+
+/***********************************************/
+
+#endif
